@@ -7,7 +7,7 @@ import json
 import yaml
 
 from configerus.config import Config
-from configerus.contrib.env import PLUGIN_ID_SOURCE_ENV
+from configerus.contrib.env import PLUGIN_ID_SOURCE_ENV_SPECIFIC
 from configerus.contrib.dict import PLUGIN_ID_SOURCE_DICT
 from configerus.contrib.files import PLUGIN_ID_SOURCE_PATH
 
@@ -56,7 +56,7 @@ def make_test_config(config: Config, sources: List):
             logger.info("Adding 'path' source '%s' [%s]: %s : %s", name, priority, path, data.keys())
             config.add_source(type, name, priority).set_path(full_path)
 
-        if type == PLUGIN_ID_SOURCE_ENV:
+        if type == PLUGIN_ID_SOURCE_ENV_SPECIFIC:
             # we can do env plugins as well
             logger.info("Adding 'env' source '%s' [%s]: %s", name, priority, data.keys())
             for env_key, env_data in data.items():
